% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{sccomp_replicate}
\alias{sccomp_replicate}
\title{sccomp_replicate}
\usage{
sccomp_replicate(
  fit,
  formula_composition = NULL,
  formula_variability = NULL,
  number_of_draws = 1,
  mcmc_seed = sample(1e+05, 1)
)
}
\arguments{
\item{fit}{The result of sccomp_estimate.}

\item{formula_composition}{A formula. The formula describing the model for differential abundance, for example ~treatment. This formula can be a sub-formula of your estimated model; in this case all other factor will be factored out.}

\item{formula_variability}{A formula. The formula describing the model for differential variability, for example ~treatment. In most cases, if differentially variability is of interest, the formula should only include the factor of interest as a large anount of data is needed to define variability depending to each factors. This formula can be a sub-formula of your estimated model; in this case all other factor will be factored out.}

\item{number_of_draws}{An integer. How may copies of the data you want to draw from the model joint posterior distribution.}

\item{mcmc_seed}{An integer. Used for Markov-chain Monte Carlo reproducibility. By default a random number is sampled from 1 to 999999. This itself can be controlled by set.seed()}
}
\value{
A tibble \code{tbl} with cell_group-wise statistics

A tibble (\code{tbl}), with the following columns:
\itemize{
\item \strong{cell_group} - A character column representing the cell group being tested.
\item \strong{sample} - A factor column representing the sample name from which data was generated.
\item \strong{generated_proportions} - A numeric column representing the proportions generated from the model.
\item \strong{generated_counts} - An integer column representing the counts generated from the model.
\item \strong{replicate} - An integer column representing the replicate number, where each row corresponds to a different replicate of the data.
}
}
\description{
This function replicates counts from a real-world dataset.
}
\examples{

message("Use the following example after having installed install.packages(\"cmdstanr\", repos = c(\"https://stan-dev.r-universe.dev/\", getOption(\"repos\")))")

\donttest{
  if (instantiate::stan_cmdstan_exists() && .Platform$OS.type == "unix") {
    data("counts_obj")

    sccomp_estimate(
      counts_obj,
      ~ type, ~1, sample, cell_group, count,
      cores = 1
    ) |>
    sccomp_replicate()
  }
}
}
